.. _response:

================
Работа с ответом
================

Объект Reponse
==============

Результатом обработки запроса является объект класса :class:`~grab.response.Response`. Вы можете получить к нему доступ через аттрибут `response`::

    g.go('http://mail.ru')
    print g.response.headers['Content-Type']

Смотрите полный перечень аттрибутов и методов объекта `Response` в API справочнике :class:`~grab.response.Response`. Самое важное, что вам нужно знать: 

:body: оригинальное тело ответа
:unicode_body(): тело ответа, приведённое к unicode-представлению
:code: HTTP-статус ответа
:headers: HTTP-заголовки ответа
:charset: кодировка документа
:cookies: кукисы ответа
:url: URL документа. В случае автоматической обработки редиректов, этот URL может отличаться от запрашиваемого.
